@@ -57,7 +57,7 @@
 #' }
 #' @param width The width of the box, using the Bootstrap grid system. This is
 #'   used for row-based layouts. The overall width of a region is 12, so the
-#'   default card width of 4 occupies 1/3 of that width. For column-based
+#'   default card width of 6 occupies 1/2 of that width. For column-based
 #'   layouts, use \code{NULL} for the width; the width is set by the column that
 #'   contains the box.
 #' @param height The height of a box, in pixels or other CSS unit. By default
@@ -105,7 +105,7 @@
 #'             status = "danger"
 #'           ),
 #'           dropdownMenu = boxDropdown(
-#'             boxDropdownItem("Link to google", href = "http://www.google.com"),
+#'             boxDropdownItem("Link to google", href = "https://www.google.com"),
 #'             boxDropdownItem("item 2", href = "#"),
 #'             dropdownDivider(),
 #'             boxDropdownItem("item 3", href = "#", icon = icon("th"))
@@ -1075,6 +1075,13 @@ bs4InfoBox <- function(title, value = NULL, subtitle = NULL, icon = shiny::icon(
 #'   library(shiny)
 #'   library(bs4Dash)
 #'
+#'   menu_tab <- lapply(1:3, function(i) {
+#'     tabPanel(
+#'       sprintf("Menu %s", i),
+#'       sprintf("Hello tab %s", i)
+#'     )
+#'   })
+#'
 #'   shinyApp(
 #'     ui = dashboardPage(
 #'       header = dashboardHeader(),
@@ -1102,10 +1109,25 @@ bs4InfoBox <- function(title, value = NULL, subtitle = NULL, icon = shiny::icon(
 #'             title = "Tab 3",
 #'             "Content 3"
 #'           )
-#'         )
+#'         ),
+#'         tabBox(
+#'          id = "mybox2",
+#'          title = "",
+#'          .list = menu_tab
+#'         ),
+#'         selectInput(
+#'         "tab",
+#'         "Selected a tab",
+#'         choices = paste("Menu", 1:3),
+#'         "Menu 2"
+#'        )
 #'       )
 #'     ),
-#'     server = function(input, output) {}
+#'     server = function(input, output, session) {
+#'       observeEvent(input$tab, {
+#'        updateTabsetPanel(session, inputId = "mybox2", input$tab)
+#'       })
+#'     }
 #'   )
 #' }
 #' @author David Granjon, \email{dgranjon@@ymail.com}
@@ -1117,7 +1139,7 @@ bs4TabCard <- function(..., id = NULL, selected = NULL, title = NULL, width = 6,
                        collapsible = TRUE, collapsed = FALSE, closable = FALSE, maximizable = FALSE,
                        icon = NULL, gradient = FALSE, boxToolSize = "sm", elevation = NULL,
                        headerBorder = TRUE, label = NULL, dropdownMenu = NULL,
-                       sidebar = NULL) {
+                       sidebar = NULL, .list = NULL) {
   side <- match.arg(side)
   if (is.null(type)) type <- "pills"
 
@@ -1127,7 +1149,7 @@ bs4TabCard <- function(..., id = NULL, selected = NULL, title = NULL, width = 6,
     id = id,
     selected = selected,
     type = type,
-    position = NULL
+    .list = .list
   )
 
   # Re-use box function
@@ -1616,7 +1638,7 @@ cardProfileItem <- function(title, description) {
 #'           ),
 #'           "Some text here!",
 #'           attachmentBlock(
-#'             image = "https://adminlte.io/themes/AdminLTE/dist/img/photo1.png",
+#'             image = "https://adminlte.io/themes/v3/dist/img/user1-128x128.jpg",
 #'             title = "Test",
 #'             href = "https://google.com",
 #'             "This is the content"
@@ -1873,4 +1895,4 @@ bs4CardLayout <- function(..., type = c("group", "deck", "columns")) {
   })
   type <- match.arg(type)
   shiny::tags$div(class = paste0("card-", type), cards)
-}
\ No newline at end of file
+}
